@@ -1,7 +1,8 @@
 from .requete import Model
 from .messenger import Messenger
 from .core import webserver, Extra as init
-from .utils import action, command, download_file, Payload
+from .utils import action, command, Payload
+from .utils import translate, download_file, simulate
 
-__version__ = '1.0.5'
+__version__ = '1.0.7'
 __author__ = 'iTeam-$'
