@@ -5,9 +5,9 @@ import uvicorn
 from .requete import Model
 from threading import Thread
 from .messenger import Messenger
-from .utils import funcs, analyse, Payload
 from fastapi.staticfiles import StaticFiles
 from fastapi import FastAPI, Request, Response
+from .utils import funcs, analyse, Cmd, Payload
 
 _req = None
 conf = None
@@ -34,15 +34,23 @@ class Extra:
         global _req
         conf = cnf
         _req = Model(cnf)
-        uvicorn.run('ampalibe:webserver', port=cnf.APP_PORT, host=cnf.APP_HOST, workers=int(cnf.WORKERS))
+        # Verif if WORKERS attribute exists
+        if hasattr(cnf, 'WORKERS'):
+            uvicorn.run('ampalibe:webserver', port=cnf.APP_PORT, host=cnf.APP_HOST, workers=int(cnf.WORKERS))
+        else:
+            uvicorn.run(webserver, port=cnf.APP_PORT, host=cnf.APP_HOST)
 
 
 class Server:
     '''
         Content of webhook
     '''
+
     @webserver.get('/')
     async def verif(request: Request):
+        '''
+            Main verification for bot server is received here
+        '''
         fb_token = request.query_params.get("hub.verify_token")
 
         if fb_token == conf.VERIF_TOKEN:
@@ -52,10 +60,18 @@ class Server:
 
     @webserver.post('/')
     async def main(request: Request):
+        '''
+            Main Requests for bot messenger is received here.
+        '''
+        testmode = request.query_params.get("testmode")
         data = await request.json()
+
+        # data analysis and decomposition
         sender_id, payload, message = analyse(data)
         _req._verif_user(sender_id)
+        # get action for the current user
         action = _req.get_action(sender_id)
+        lang = _req.get_lang(sender_id)
 
         if payload in ('/__next', '/__more'):
             bot = Messenger(conf.ACCESS_TOKEN)
@@ -73,23 +89,38 @@ class Server:
             os.remove(f'assets/private/.__{sender_id}')
 
         if action and funcs['action'].get(action):
-            Thread(
-                target=funcs['action'].get(action),
-                kwargs={'sender_id': sender_id, 'cmd': payload, 'message': message}
-            ).start()
+            '''
+                CASE an action is set.
+            '''
+            kw = {
+                'sender_id': sender_id, 'cmd': payload,
+                'message': message, 'lang': lang
+            }
+
+            if testmode:
+                 funcs['action'].get(action)(**kw)
+            else:
+                Thread(
+                    target=funcs['action'].get(action),
+                    kwargs=kw
+                ).start()
         else:
             if action:
                 print(
-                    f'Warning! action: {action} Not found',
+                    f'Warning! action: "{action}" Not found',
                     file=sys.stderr
                 )
             payload, kw = Payload.trt_payload_in(payload)
             kw['sender_id'] = sender_id
-            kw['cmd'] = payload
+            kw['cmd'] = Cmd(payload)  # Remake payload to CMD object
             kw['message'] = message
-            Thread(
-                target=funcs['commande'].get(payload.split()[0], funcs['commande']['/']),
-                kwargs=kw
-            ).start()
+            kw['lang'] = lang
+            if testmode:
+                funcs['commande'].get(payload.split()[0], funcs['commande']['/'])(**kw)
+            else:
+                Thread(
+                    target=funcs['commande'].get(payload.split()[0], funcs['commande']['/']),
+                    kwargs=kw
+                ).start()
 
         return {'status': 'ok'}
