@@ -1,9 +1,29 @@
+import os
+import sys
+import json
 import requests
 import urllib.parse
 
 
 funcs = {'commande': {}, 'action': {}}
 
+class Cmd(str):
+    '''
+        Object for text of message
+    '''
+    __atts = []
+
+    def __init__(self, text):
+        str.__init__(text)
+
+    def set_atts(self, atts):
+        for att in atts:
+            self.__atts.append(att)
+
+    @property
+    def attachments(self):
+        return self.__atts
+
 
 class Payload:
     '''
@@ -72,17 +92,21 @@ def analyse(data):
                 if message['message'].get('attachments'):
                     # Get file name
                     data = message['message'].get('attachments')
-                    return sender_id, ','.join(list(map(struct_atts, data))), message
+                    # creation de l'objet cmd personalisé
+                    atts = list(map(struct_atts, data))
+                    cmd = Cmd(atts[0])
+                    cmd.set_atts(atts)
+                    return sender_id, cmd, message
                 elif message['message'].get('quick_reply'):
                     # if the response is a quick reply
-                    return  sender_id, message['message']['quick_reply'].get('payload'), message
+                    return  sender_id, Cmd(message['message']['quick_reply'].get('payload')), message
                 elif message['message'].get('text'):
                     # if the response is a simple text
-                    return  sender_id, message['message'].get('text'), message
+                    return  sender_id, Cmd(message['message'].get('text')), message
             if message.get('postback'):
                 recipient_id = message['sender']['id']
                 pst_payload = message['postback']['payload']
-                return recipient_id, pst_payload, message
+                return recipient_id, Cmd(pst_payload), message
 
 
 def command(*args, **kwargs):
@@ -119,4 +143,72 @@ def download_file(url, file):
     with open(file, 'wb') as f:
         f.write(res.content)
 
-    return file
\ No newline at end of file
+    return file
+
+def translate(key, lang):
+    '''
+        translate a keyword or sentence
+
+        @params:
+        
+            key: the key used in langs.json file 
+            
+            lang: the langage code in format fr, en, mg, ...
+
+        this function uses the langs.json file.
+    '''
+    if not lang:
+        return key
+
+    if not os.path.isfile("langs.json"):
+        print(
+            "Warning! langs.json not found",
+            file=sys.stderr
+        )
+        from .source import langs
+        with open("langs.json", "w") as fichier:
+            fichier.write(langs)
+            print('langs.json created!')
+        return key
+
+    with open("langs.json") as fichier:
+        trans = json.load(fichier)
+
+    keyword = trans.get(key)
+
+    if keyword:
+        if keyword.get(lang):
+            return keyword.get(lang)
+    return key
+
+
+def simulate(message, user, conf, **params):
+    '''
+        Simulate a message send by an user
+    '''
+    data_json = {
+        "object": "page",
+        "entry": [
+            {
+                "messaging": [
+                    {
+                        "message":
+                            {
+                                "text": mes,
+                            },
+                        "sender":
+                            {
+                                "id": user
+                            }
+                    }
+                ]
+            }
+        ]
+    }
+    header = {'content-type': 'application/json; charset=utf-8'}
+    return requests.post(
+        f'http://127.0.0.1:{conf.APP_PORT}',
+        json=data_json,
+        headers=header,
+        params=params
+    )
\ No newline at end of file
